# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import common_pb2 as vdp_dot_pipeline_dot_v1beta_dot_common__pb2
from vdp.pipeline.v1beta import component_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_component__definition__pb2
from vdp.pipeline.v1beta import integration_pb2 as vdp_dot_pipeline_dot_v1beta_dot_integration__pb2
from vdp.pipeline.v1beta import pipeline_pb2 as vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2
from vdp.pipeline.v1beta import secret_pb2 as vdp_dot_pipeline_dot_v1beta_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1vdp/pipeline/v1beta/pipeline_public_service.proto\x12\x13vdp.pipeline.v1beta\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a vdp/pipeline/v1beta/common.proto\x1a.vdp/pipeline/v1beta/component_definition.proto\x1a%vdp/pipeline/v1beta/integration.proto\x1a\"vdp/pipeline/v1beta/pipeline.proto\x1a vdp/pipeline/v1beta/secret.proto2\xe8\xb1\x01\n\x15PipelinePublicService\x12\x9e\x01\n\x08Liveness\x12$.vdp.pipeline.v1beta.LivenessRequest\x1a%.vdp.pipeline.v1beta.LivenessResponse\"E\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/\x12\x12/v1beta/__livenessZ\x19\x12\x17/v1beta/health/pipeline\x12\x87\x01\n\tReadiness\x12%.vdp.pipeline.v1beta.ReadinessRequest\x1a&.vdp.pipeline.v1beta.ReadinessResponse\"+\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x15\x12\x13/v1beta/__readiness\x12\x98\x01\n\x0bGetHubStats\x12\'.vdp.pipeline.v1beta.GetHubStatsRequest\x1a(.vdp.pipeline.v1beta.GetHubStatsResponse\"6\x92\x41\n\n\x08Pipeline\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x13\x12\x11/v1beta/hub-stats\x12\x8e\x01\n\rListPipelines\x12).vdp.pipeline.v1beta.ListPipelinesRequest\x1a*.vdp.pipeline.v1beta.ListPipelinesResponse\"&\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02\x13\x12\x11/v1beta/pipelines\x12\xb6\x01\n\x0eLookUpPipeline\x12*.vdp.pipeline.v1beta.LookUpPipelineRequest\x1a+.vdp.pipeline.v1beta.LookUpPipelineResponse\"K\x92\x41\n\n\x08Pipeline\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02(\x12&/v1beta/{permalink=pipelines/*}/lookUp\x12\xc3\x01\n\x16ListNamespacePipelines\x12\x32.vdp.pipeline.v1beta.ListNamespacePipelinesRequest\x1a\x33.vdp.pipeline.v1beta.ListNamespacePipelinesResponse\"@\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02-\x12+/v1beta/namespaces/{namespace_id}/pipelines\x12\xd0\x01\n\x17\x43reateNamespacePipeline\x12\x33.vdp.pipeline.v1beta.CreateNamespacePipelineRequest\x1a\x34.vdp.pipeline.v1beta.CreateNamespacePipelineResponse\"J\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02\x37\"+/v1beta/namespaces/{namespace_id}/pipelines:\x08pipeline\x12\xcb\x01\n\x14GetNamespacePipeline\x12\x30.vdp.pipeline.v1beta.GetNamespacePipelineRequest\x1a\x31.vdp.pipeline.v1beta.GetNamespacePipelineResponse\"N\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02;\x12\x39/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}\x12\xde\x01\n\x17UpdateNamespacePipeline\x12\x33.vdp.pipeline.v1beta.UpdateNamespacePipelineRequest\x1a\x34.vdp.pipeline.v1beta.UpdateNamespacePipelineResponse\"X\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02\x45\x32\x39/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}:\x08pipeline\x12\xd4\x01\n\x17\x44\x65leteNamespacePipeline\x12\x33.vdp.pipeline.v1beta.DeleteNamespacePipelineRequest\x1a\x34.vdp.pipeline.v1beta.DeleteNamespacePipelineResponse\"N\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02;*9/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}\x12\xe6\x01\n\x19ValidateNamespacePipeline\x12\x35.vdp.pipeline.v1beta.ValidateNamespacePipelineRequest\x1a\x36.vdp.pipeline.v1beta.ValidateNamespacePipelineResponse\"Z\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02G\"B/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/validate:\x01*\x12\xde\x01\n\x17RenameNamespacePipeline\x12\x33.vdp.pipeline.v1beta.RenameNamespacePipelineRequest\x1a\x34.vdp.pipeline.v1beta.RenameNamespacePipelineResponse\"X\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02\x45\"@/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/rename:\x01*\x12\xda\x01\n\x16\x43loneNamespacePipeline\x12\x32.vdp.pipeline.v1beta.CloneNamespacePipelineRequest\x1a\x33.vdp.pipeline.v1beta.CloneNamespacePipelineResponse\"W\x92\x41\n\n\x08Pipeline\x82\xd3\xe4\x93\x02\x44\"?/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/clone:\x01*\x12\xf3\x01\n\x1aSendNamespacePipelineEvent\x12\x36.vdp.pipeline.v1beta.SendNamespacePipelineEventRequest\x1a\x37.vdp.pipeline.v1beta.SendNamespacePipelineEventResponse\"d\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02N\"@/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/events:\x04\x64\x61tab\x04\x64\x61ta\x12\x9e\x02\n!SendNamespacePipelineReleaseEvent\x12=.vdp.pipeline.v1beta.SendNamespacePipelineReleaseEventRequest\x1a>.vdp.pipeline.v1beta.SendNamespacePipelineReleaseEventResponse\"z\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x64\"V/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}/events:\x04\x64\x61tab\x04\x64\x61ta\x12\x86\x03\n\x18TriggerNamespacePipeline\x12\x34.vdp.pipeline.v1beta.TriggerNamespacePipelineRequest\x1a\x35.vdp.pipeline.v1beta.TriggerNamespacePipelineResponse\"\xfc\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\x46\"A/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/trigger:\x01*\x12\xad\x03\n\"TriggerNamespacePipelineWithStream\x12>.vdp.pipeline.v1beta.TriggerNamespacePipelineWithStreamRequest\x1a?.vdp.pipeline.v1beta.TriggerNamespacePipelineWithStreamResponse\"\x83\x02\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02M\"H/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/trigger-stream:\x01*0\x01\x12\x9b\x03\n\x1dTriggerAsyncNamespacePipeline\x12\x39.vdp.pipeline.v1beta.TriggerAsyncNamespacePipelineRequest\x1a:.vdp.pipeline.v1beta.TriggerAsyncNamespacePipelineResponse\"\x82\x02\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02L\"G/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/trigger-async:\x01*\x12\xfa\x01\n\x1e\x43reateNamespacePipelineRelease\x12:.vdp.pipeline.v1beta.CreateNamespacePipelineReleaseRequest\x1a;.vdp.pipeline.v1beta.CreateNamespacePipelineReleaseResponse\"_\x92\x41\t\n\x07Release\x82\xd3\xe4\x93\x02M\"B/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases:\x07release\x12\xee\x01\n\x1dListNamespacePipelineReleases\x12\x39.vdp.pipeline.v1beta.ListNamespacePipelineReleasesRequest\x1a:.vdp.pipeline.v1beta.ListNamespacePipelineReleasesResponse\"V\x92\x41\t\n\x07Release\x82\xd3\xe4\x93\x02\x44\x12\x42/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases\x12\xf5\x01\n\x1bGetNamespacePipelineRelease\x12\x37.vdp.pipeline.v1beta.GetNamespacePipelineReleaseRequest\x1a\x38.vdp.pipeline.v1beta.GetNamespacePipelineReleaseResponse\"c\x92\x41\t\n\x07Release\x82\xd3\xe4\x93\x02Q\x12O/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}\x12\x87\x02\n\x1eUpdateNamespacePipelineRelease\x12:.vdp.pipeline.v1beta.UpdateNamespacePipelineReleaseRequest\x1a;.vdp.pipeline.v1beta.UpdateNamespacePipelineReleaseResponse\"l\x92\x41\t\n\x07Release\x82\xd3\xe4\x93\x02Z2O/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}:\x07release\x12\xfe\x01\n\x1e\x44\x65leteNamespacePipelineRelease\x12:.vdp.pipeline.v1beta.DeleteNamespacePipelineReleaseRequest\x1a;.vdp.pipeline.v1beta.DeleteNamespacePipelineReleaseResponse\"c\x92\x41\t\n\x07Release\x82\xd3\xe4\x93\x02Q*O/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}\x12\x84\x02\n\x1d\x43loneNamespacePipelineRelease\x12\x39.vdp.pipeline.v1beta.CloneNamespacePipelineReleaseRequest\x1a:.vdp.pipeline.v1beta.CloneNamespacePipelineReleaseResponse\"l\x92\x41\t\n\x07Release\x82\xd3\xe4\x93\x02Z\"U/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}/clone:\x01*\x12\xb1\x03\n\x1fTriggerNamespacePipelineRelease\x12;.vdp.pipeline.v1beta.TriggerNamespacePipelineReleaseRequest\x1a<.vdp.pipeline.v1beta.TriggerNamespacePipelineReleaseResponse\"\x92\x02\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\\\"W/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}/trigger:\x01*\x12\xc6\x03\n$TriggerAsyncNamespacePipelineRelease\x12@.vdp.pipeline.v1beta.TriggerAsyncNamespacePipelineReleaseRequest\x1a\x41.vdp.pipeline.v1beta.TriggerAsyncNamespacePipelineReleaseResponse\"\x98\x02\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\x62\"]/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}/trigger-async:\x01*\x12\xc4\x01\n\x15\x43reateNamespaceSecret\x12\x31.vdp.pipeline.v1beta.CreateNamespaceSecretRequest\x1a\x32.vdp.pipeline.v1beta.CreateNamespaceSecretResponse\"D\x92\x41\x08\n\x06Secret\x82\xd3\xe4\x93\x02\x33\")/v1beta/namespaces/{namespace_id}/secrets:\x06secret\x12\xb9\x01\n\x14ListNamespaceSecrets\x12\x30.vdp.pipeline.v1beta.ListNamespaceSecretsRequest\x1a\x31.vdp.pipeline.v1beta.ListNamespaceSecretsResponse\"<\x92\x41\x08\n\x06Secret\x82\xd3\xe4\x93\x02+\x12)/v1beta/namespaces/{namespace_id}/secrets\x12\xbf\x01\n\x12GetNamespaceSecret\x12..vdp.pipeline.v1beta.GetNamespaceSecretRequest\x1a/.vdp.pipeline.v1beta.GetNamespaceSecretResponse\"H\x92\x41\x08\n\x06Secret\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/namespaces/{namespace_id}/secrets/{secret_id}\x12\xd0\x01\n\x15UpdateNamespaceSecret\x12\x31.vdp.pipeline.v1beta.UpdateNamespaceSecretRequest\x1a\x32.vdp.pipeline.v1beta.UpdateNamespaceSecretResponse\"P\x92\x41\x08\n\x06Secret\x82\xd3\xe4\x93\x02?25/v1beta/namespaces/{namespace_id}/secrets/{secret_id}:\x06secret\x12\xc8\x01\n\x15\x44\x65leteNamespaceSecret\x12\x31.vdp.pipeline.v1beta.DeleteNamespaceSecretRequest\x1a\x32.vdp.pipeline.v1beta.DeleteNamespaceSecretResponse\"H\x92\x41\x08\n\x06Secret\x82\xd3\xe4\x93\x02\x37*5/v1beta/namespaces/{namespace_id}/secrets/{secret_id}\x12\xbc\x01\n\x18ListComponentDefinitions\x12\x34.vdp.pipeline.v1beta.ListComponentDefinitionsRequest\x1a\x35.vdp.pipeline.v1beta.ListComponentDefinitionsResponse\"3\x92\x41\x0b\n\tComponent\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1beta/component-definitions\x12\xb9\x02\n\x0cGetOperation\x12(.vdp.pipeline.v1beta.GetOperationRequest\x1a).vdp.pipeline.v1beta.GetOperationResponse\"\xd3\x01\x92\x41\xa6\x01\n\x07Triggerr\x9a\x01\n\x97\x01\n\x15Instill-Requester-Uid\x12|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02#\x12!/v1beta/operations/{operation_id}\x12\xbe\x01\n\x12\x43reateUserPipeline\x12..vdp.pipeline.v1beta.CreateUserPipelineRequest\x1a/.vdp.pipeline.v1beta.CreateUserPipelineResponse\"G\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\"\"/v1beta/{parent=users/*}/pipelines:\x08pipeline\x12\xb1\x01\n\x11ListUserPipelines\x12-.vdp.pipeline.v1beta.ListUserPipelinesRequest\x1a..vdp.pipeline.v1beta.ListUserPipelinesResponse\"=\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02$\x12\"/v1beta/{parent=users/*}/pipelines\x12\xab\x01\n\x0fGetUserPipeline\x12+.vdp.pipeline.v1beta.GetUserPipelineRequest\x1a,.vdp.pipeline.v1beta.GetUserPipelineResponse\"=\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02$\x12\"/v1beta/{name=users/*/pipelines/*}\x12\xc7\x01\n\x12UpdateUserPipeline\x12..vdp.pipeline.v1beta.UpdateUserPipelineRequest\x1a/.vdp.pipeline.v1beta.UpdateUserPipelineResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37\x32+/v1beta/{pipeline.name=users/*/pipelines/*}:\x08pipeline\x12\xb4\x01\n\x12\x44\x65leteUserPipeline\x12..vdp.pipeline.v1beta.DeleteUserPipelineRequest\x1a/.vdp.pipeline.v1beta.DeleteUserPipelineResponse\"=\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02$*\"/v1beta/{name=users/*/pipelines/*}\x12\xc6\x01\n\x14ValidateUserPipeline\x12\x30.vdp.pipeline.v1beta.ValidateUserPipelineRequest\x1a\x31.vdp.pipeline.v1beta.ValidateUserPipelineResponse\"I\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x30\"+/v1beta/{name=users/*/pipelines/*}/validate:\x01*\x12\xbe\x01\n\x12RenameUserPipeline\x12..vdp.pipeline.v1beta.RenameUserPipelineRequest\x1a/.vdp.pipeline.v1beta.RenameUserPipelineResponse\"G\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\")/v1beta/{name=users/*/pipelines/*}/rename:\x01*\x12\xc2\x01\n\x13TriggerUserPipeline\x12/.vdp.pipeline.v1beta.TriggerUserPipelineRequest\x1a\x30.vdp.pipeline.v1beta.TriggerUserPipelineResponse\"H\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/\"*/v1beta/{name=users/*/pipelines/*}/trigger:\x01*\x12\xe9\x01\n\x1dTriggerUserPipelineWithStream\x12\x39.vdp.pipeline.v1beta.TriggerUserPipelineWithStreamRequest\x1a:.vdp.pipeline.v1beta.TriggerUserPipelineWithStreamResponse\"O\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x36\"1/v1beta/{name=users/*/pipelines/*}/trigger-stream:\x01*0\x01\x12\xd6\x01\n\x18TriggerAsyncUserPipeline\x12\x34.vdp.pipeline.v1beta.TriggerAsyncUserPipelineRequest\x1a\x35.vdp.pipeline.v1beta.TriggerAsyncUserPipelineResponse\"M\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x34\"//v1beta/{name=users/*/pipelines/*}/triggerAsync:\x01*\x12\xdd\x01\n\x19\x43reateUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.CreateUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.CreateUserPipelineReleaseResponse\"Q\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x38\"-/v1beta/{parent=users/*/pipelines/*}/releases:\x07release\x12\xd1\x01\n\x18ListUserPipelineReleases\x12\x34.vdp.pipeline.v1beta.ListUserPipelineReleasesRequest\x1a\x35.vdp.pipeline.v1beta.ListUserPipelineReleasesResponse\"H\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/\x12-/v1beta/{parent=users/*/pipelines/*}/releases\x12\xcb\x01\n\x16GetUserPipelineRelease\x12\x32.vdp.pipeline.v1beta.GetUserPipelineReleaseRequest\x1a\x33.vdp.pipeline.v1beta.GetUserPipelineReleaseResponse\"H\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/\x12-/v1beta/{name=users/*/pipelines/*/releases/*}\x12\xe5\x01\n\x19UpdateUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.UpdateUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.UpdateUserPipelineReleaseResponse\"Y\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02@25/v1beta/{release.name=users/*/pipelines/*/releases/*}:\x07release\x12\xd4\x01\n\x19\x44\x65leteUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.DeleteUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.DeleteUserPipelineReleaseResponse\"H\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/*-/v1beta/{name=users/*/pipelines/*/releases/*}\x12\xdf\x01\n\x1aRestoreUserPipelineRelease\x12\x36.vdp.pipeline.v1beta.RestoreUserPipelineReleaseRequest\x1a\x37.vdp.pipeline.v1beta.RestoreUserPipelineReleaseResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37\"5/v1beta/{name=users/*/pipelines/*/releases/*}/restore\x12\xde\x01\n\x19RenameUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.RenameUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.RenameUserPipelineReleaseResponse\"R\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x39\"4/v1beta/{name=users/*/pipelines/*/releases/*}/rename:\x01*\x12\xe2\x01\n\x1aTriggerUserPipelineRelease\x12\x36.vdp.pipeline.v1beta.TriggerUserPipelineReleaseRequest\x1a\x37.vdp.pipeline.v1beta.TriggerUserPipelineReleaseResponse\"S\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02:\"5/v1beta/{name=users/*/pipelines/*/releases/*}/trigger:\x01*\x12\xf6\x01\n\x1fTriggerAsyncUserPipelineRelease\x12;.vdp.pipeline.v1beta.TriggerAsyncUserPipelineReleaseRequest\x1a<.vdp.pipeline.v1beta.TriggerAsyncUserPipelineReleaseResponse\"X\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02?\":/v1beta/{name=users/*/pipelines/*/releases/*}/triggerAsync:\x01*\x12\xde\x01\n\x1a\x43reateOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.CreateOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.CreateOrganizationPipelineResponse\"O\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x36\"*/v1beta/{parent=organizations/*}/pipelines:\x08pipeline\x12\xd1\x01\n\x19ListOrganizationPipelines\x12\x35.vdp.pipeline.v1beta.ListOrganizationPipelinesRequest\x1a\x36.vdp.pipeline.v1beta.ListOrganizationPipelinesResponse\"E\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12*/v1beta/{parent=organizations/*}/pipelines\x12\xcb\x01\n\x17GetOrganizationPipeline\x12\x33.vdp.pipeline.v1beta.GetOrganizationPipelineRequest\x1a\x34.vdp.pipeline.v1beta.GetOrganizationPipelineResponse\"E\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12*/v1beta/{name=organizations/*/pipelines/*}\x12\xe7\x01\n\x1aUpdateOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.UpdateOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.UpdateOrganizationPipelineResponse\"X\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02?23/v1beta/{pipeline.name=organizations/*/pipelines/*}:\x08pipeline\x12\xd4\x01\n\x1a\x44\x65leteOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.DeleteOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.DeleteOrganizationPipelineResponse\"E\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,**/v1beta/{name=organizations/*/pipelines/*}\x12\xe6\x01\n\x1cValidateOrganizationPipeline\x12\x38.vdp.pipeline.v1beta.ValidateOrganizationPipelineRequest\x1a\x39.vdp.pipeline.v1beta.ValidateOrganizationPipelineResponse\"Q\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x38\"3/v1beta/{name=organizations/*/pipelines/*}/validate:\x01*\x12\xde\x01\n\x1aRenameOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.RenameOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.RenameOrganizationPipelineResponse\"O\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x36\"1/v1beta/{name=organizations/*/pipelines/*}/rename:\x01*\x12\xfd\x01\n!TriggerOrganizationPipelineStream\x12=.vdp.pipeline.v1beta.TriggerOrganizationPipelineStreamRequest\x1a>.vdp.pipeline.v1beta.TriggerOrganizationPipelineStreamResponse\"W\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02>\"9/v1beta/{name=organizations/*/pipelines/*}/trigger-stream:\x01*0\x01\x12\xe2\x01\n\x1bTriggerOrganizationPipeline\x12\x37.vdp.pipeline.v1beta.TriggerOrganizationPipelineRequest\x1a\x38.vdp.pipeline.v1beta.TriggerOrganizationPipelineResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37\"2/v1beta/{name=organizations/*/pipelines/*}/trigger:\x01*\x12\xf6\x01\n TriggerAsyncOrganizationPipeline\x12<.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineRequest\x1a=.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineResponse\"U\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02<\"7/v1beta/{name=organizations/*/pipelines/*}/triggerAsync:\x01*\x12\xfd\x01\n!CreateOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.CreateOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.CreateOrganizationPipelineReleaseResponse\"Y\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02@\"5/v1beta/{parent=organizations/*/pipelines/*}/releases:\x07release\x12\xf1\x01\n ListOrganizationPipelineReleases\x12<.vdp.pipeline.v1beta.ListOrganizationPipelineReleasesRequest\x1a=.vdp.pipeline.v1beta.ListOrganizationPipelineReleasesResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/{parent=organizations/*/pipelines/*}/releases\x12\xeb\x01\n\x1eGetOrganizationPipelineRelease\x12:.vdp.pipeline.v1beta.GetOrganizationPipelineReleaseRequest\x1a;.vdp.pipeline.v1beta.GetOrganizationPipelineReleaseResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/{name=organizations/*/pipelines/*/releases/*}\x12\x85\x02\n!UpdateOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.UpdateOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.UpdateOrganizationPipelineReleaseResponse\"a\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02H2=/v1beta/{release.name=organizations/*/pipelines/*/releases/*}:\x07release\x12\xf4\x01\n!DeleteOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.DeleteOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.DeleteOrganizationPipelineReleaseResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37*5/v1beta/{name=organizations/*/pipelines/*/releases/*}\x12\xff\x01\n\"RestoreOrganizationPipelineRelease\x12>.vdp.pipeline.v1beta.RestoreOrganizationPipelineReleaseRequest\x1a?.vdp.pipeline.v1beta.RestoreOrganizationPipelineReleaseResponse\"X\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02?\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/restore\x12\xfe\x01\n!RenameOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.RenameOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.RenameOrganizationPipelineReleaseResponse\"Z\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x41\"</v1beta/{name=organizations/*/pipelines/*/releases/*}/rename:\x01*\x12\x82\x02\n\"TriggerOrganizationPipelineRelease\x12>.vdp.pipeline.v1beta.TriggerOrganizationPipelineReleaseRequest\x1a?.vdp.pipeline.v1beta.TriggerOrganizationPipelineReleaseResponse\"[\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x42\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/trigger:\x01*\x12\x96\x02\n\'TriggerAsyncOrganizationPipelineRelease\x12\x43.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineReleaseRequest\x1a\x44.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineReleaseResponse\"`\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02G\"B/v1beta/{name=organizations/*/pipelines/*/releases/*}/triggerAsync:\x01*\x12\xc1\x01\n\x18ListConnectorDefinitions\x12\x34.vdp.pipeline.v1beta.ListConnectorDefinitionsRequest\x1a\x35.vdp.pipeline.v1beta.ListConnectorDefinitionsResponse\"8\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1beta/connector-definitions\x12\xc4\x01\n\x16GetConnectorDefinition\x12\x32.vdp.pipeline.v1beta.GetConnectorDefinitionRequest\x1a\x33.vdp.pipeline.v1beta.GetConnectorDefinitionResponse\"A\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02(\x12&/v1beta/{name=connector-definitions/*}\x12\xbd\x01\n\x17ListOperatorDefinitions\x12\x33.vdp.pipeline.v1beta.ListOperatorDefinitionsRequest\x1a\x34.vdp.pipeline.v1beta.ListOperatorDefinitionsResponse\"7\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1beta/operator-definitions\x12\xc0\x01\n\x15GetOperatorDefinition\x12\x31.vdp.pipeline.v1beta.GetOperatorDefinitionRequest\x1a\x32.vdp.pipeline.v1beta.GetOperatorDefinitionResponse\"@\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\'\x12%/v1beta/{name=operator-definitions/*}\x12\x8c\x01\n\tCheckName\x12%.vdp.pipeline.v1beta.CheckNameRequest\x1a&.vdp.pipeline.v1beta.CheckNameResponse\"0\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x17\"\x12/v1beta/check-name:\x01*\x12\xb4\x01\n\x10\x43reateUserSecret\x12,.vdp.pipeline.v1beta.CreateUserSecretRequest\x1a-.vdp.pipeline.v1beta.CreateUserSecretResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02*\" /v1beta/{parent=users/*}/secrets:\x06secret\x12\xa9\x01\n\x0fListUserSecrets\x12+.vdp.pipeline.v1beta.ListUserSecretsRequest\x1a,.vdp.pipeline.v1beta.ListUserSecretsResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"\x12 /v1beta/{parent=users/*}/secrets\x12\xa3\x01\n\rGetUserSecret\x12).vdp.pipeline.v1beta.GetUserSecretRequest\x1a*.vdp.pipeline.v1beta.GetUserSecretResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"\x12 /v1beta/{name=users/*/secrets/*}\x12\xbb\x01\n\x10UpdateUserSecret\x12,.vdp.pipeline.v1beta.UpdateUserSecretRequest\x1a-.vdp.pipeline.v1beta.UpdateUserSecretResponse\"J\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x32\'/v1beta/{secret.name=users/*/secrets/*}:\x06secret\x12\xac\x01\n\x10\x44\x65leteUserSecret\x12,.vdp.pipeline.v1beta.DeleteUserSecretRequest\x1a-.vdp.pipeline.v1beta.DeleteUserSecretResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"* /v1beta/{name=users/*/secrets/*}\x12\xd4\x01\n\x18\x43reateOrganizationSecret\x12\x34.vdp.pipeline.v1beta.CreateOrganizationSecretRequest\x1a\x35.vdp.pipeline.v1beta.CreateOrganizationSecretResponse\"K\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x32\"(/v1beta/{parent=organizations/*}/secrets:\x06secret\x12\xc9\x01\n\x17ListOrganizationSecrets\x12\x33.vdp.pipeline.v1beta.ListOrganizationSecretsRequest\x1a\x34.vdp.pipeline.v1beta.ListOrganizationSecretsResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02*\x12(/v1beta/{parent=organizations/*}/secrets\x12\xc3\x01\n\x15GetOrganizationSecret\x12\x31.vdp.pipeline.v1beta.GetOrganizationSecretRequest\x1a\x32.vdp.pipeline.v1beta.GetOrganizationSecretResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02*\x12(/v1beta/{name=organizations/*/secrets/*}\x12\xdb\x01\n\x18UpdateOrganizationSecret\x12\x34.vdp.pipeline.v1beta.UpdateOrganizationSecretRequest\x1a\x35.vdp.pipeline.v1beta.UpdateOrganizationSecretResponse\"R\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x39\x32//v1beta/{secret.name=organizations/*/secrets/*}:\x06secret\x12\xcc\x01\n\x18\x44\x65leteOrganizationSecret\x12\x34.vdp.pipeline.v1beta.DeleteOrganizationSecretRequest\x1a\x35.vdp.pipeline.v1beta.DeleteOrganizationSecretResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02**(/v1beta/{name=organizations/*/secrets/*}\x12\xe8\x02\n\x10ListPipelineRuns\x12,.vdp.pipeline.v1beta.ListPipelineRunsRequest\x1a-.vdp.pipeline.v1beta.ListPipelineRunsResponse\"\xf6\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02@\x12>/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/runs\x12\xe3\x02\n\x11ListComponentRuns\x12-.vdp.pipeline.v1beta.ListComponentRunsRequest\x1a..vdp.pipeline.v1beta.ListComponentRunsResponse\"\xee\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\x38\x12\x36/v1beta/pipeline-runs/{pipeline_run_id}/component-runs\x12\xf1\x02\n\x1dListPipelineRunsByCreditOwner\x12\x39.vdp.pipeline.v1beta.ListPipelineRunsByCreditOwnerRequest\x1a:.vdp.pipeline.v1beta.ListPipelineRunsByCreditOwnerResponse\"\xd8\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\"\x12 /v1beta/dashboard/pipelines/runs\x12\xce\x01\n\x18ListNamespaceConnections\x12\x34.vdp.pipeline.v1beta.ListNamespaceConnectionsRequest\x1a\x35.vdp.pipeline.v1beta.ListNamespaceConnectionsResponse\"E\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02/\x12-/v1beta/namespaces/{namespace_id}/connections\x12\xd8\x01\n\x16GetNamespaceConnection\x12\x32.vdp.pipeline.v1beta.GetNamespaceConnectionRequest\x1a\x33.vdp.pipeline.v1beta.GetNamespaceConnectionResponse\"U\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02?\x12=/v1beta/namespaces/{namespace_id}/connections/{connection_id}\x12\xe8\x01\n\x19\x43reateNamespaceConnection\x12\x35.vdp.pipeline.v1beta.CreateNamespaceConnectionRequest\x1a\x36.vdp.pipeline.v1beta.CreateNamespaceConnectionResponse\"\\\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02\x46\"8/v1beta/namespaces/{connection.namespace_id}/connections:\nconnection\x12\xf8\x01\n\x19UpdateNamespaceConnection\x12\x35.vdp.pipeline.v1beta.UpdateNamespaceConnectionRequest\x1a\x36.vdp.pipeline.v1beta.UpdateNamespaceConnectionResponse\"l\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02V2H/v1beta/namespaces/{connection.namespace_id}/connections/{connection_id}:\nconnection\x12\xe1\x01\n\x19\x44\x65leteNamespaceConnection\x12\x35.vdp.pipeline.v1beta.DeleteNamespaceConnectionRequest\x1a\x36.vdp.pipeline.v1beta.DeleteNamespaceConnectionResponse\"U\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02?*=/v1beta/namespaces/{namespace_id}/connections/{connection_id}\x12\xe0\x01\n\x17TestNamespaceConnection\x12\x33.vdp.pipeline.v1beta.TestNamespaceConnectionRequest\x1a\x34.vdp.pipeline.v1beta.TestNamespaceConnectionResponse\"Z\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02\x44\"B/v1beta/namespaces/{namespace_id}/connections/{connection_id}/test\x12\x82\x02\n\x1dListPipelineIDsByConnectionID\x12\x39.vdp.pipeline.v1beta.ListPipelineIDsByConnectionIDRequest\x1a:.vdp.pipeline.v1beta.ListPipelineIDsByConnectionIDResponse\"j\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02T\x12R/v1beta/namespaces/{namespace_id}/connections/{connection_id}/referenced-pipelines\x12\x9d\x01\n\x10ListIntegrations\x12,.vdp.pipeline.v1beta.ListIntegrationsRequest\x1a-.vdp.pipeline.v1beta.ListIntegrationsResponse\",\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02\x16\x12\x14/v1beta/integrations\x12\xa8\x01\n\x0eGetIntegration\x12*.vdp.pipeline.v1beta.GetIntegrationRequest\x1a+.vdp.pipeline.v1beta.GetIntegrationResponse\"=\x92\x41\r\n\x0bIntegration\x82\xd3\xe4\x93\x02\'\x12%/v1beta/integrations/{integration_id}\x1a\x19\x92\x41\x16\x12\x14Public VDP endpointsB\xe9\x01\n\x17\x63om.vdp.pipeline.v1betaB\x1aPipelinePublicServiceProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\032PipelinePublicServiceProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _PIPELINEPUBLICSERVICE._options = None
  _PIPELINEPUBLICSERVICE._serialized_options = b'\222A\026\022\024Public VDP endpoints'
  _PIPELINEPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/\022\022/v1beta/__livenessZ\031\022\027/v1beta/health/pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\025\022\023/v1beta/__readiness'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetHubStats']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetHubStats']._serialized_options = b'\222A\n\n\010Pipeline\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\023\022\021/v1beta/hub-stats'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelines']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\002\023\022\021/v1beta/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpPipeline']._serialized_options = b'\222A\n\n\010Pipeline\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002(\022&/v1beta/{permalink=pipelines/*}/lookUp'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListNamespacePipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListNamespacePipelines']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\002-\022+/v1beta/namespaces/{namespace_id}/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateNamespacePipeline']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\0027\"+/v1beta/namespaces/{namespace_id}/pipelines:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetNamespacePipeline']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\002;\0229/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateNamespacePipeline']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\002E29/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteNamespacePipeline']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\002;*9/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateNamespacePipeline']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\002G\"B/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/validate:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameNamespacePipeline']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\002E\"@/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneNamespacePipeline']._serialized_options = b'\222A\n\n\010Pipeline\202\323\344\223\002D\"?/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/clone:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['SendNamespacePipelineEvent']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['SendNamespacePipelineEvent']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002N\"@/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/events:\004datab\004data'
  _PIPELINEPUBLICSERVICE.methods_by_name['SendNamespacePipelineReleaseEvent']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['SendNamespacePipelineReleaseEvent']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002d\"V/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}/events:\004datab\004data'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerNamespacePipeline']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002F\"A/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerNamespacePipelineWithStream']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerNamespacePipelineWithStream']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002M\"H/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/trigger-stream:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncNamespacePipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncNamespacePipeline']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002L\"G/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/trigger-async:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateNamespacePipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateNamespacePipelineRelease']._serialized_options = b'\222A\t\n\007Release\202\323\344\223\002M\"B/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListNamespacePipelineReleases']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListNamespacePipelineReleases']._serialized_options = b'\222A\t\n\007Release\202\323\344\223\002D\022B/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetNamespacePipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetNamespacePipelineRelease']._serialized_options = b'\222A\t\n\007Release\202\323\344\223\002Q\022O/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateNamespacePipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateNamespacePipelineRelease']._serialized_options = b'\222A\t\n\007Release\202\323\344\223\002Z2O/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteNamespacePipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteNamespacePipelineRelease']._serialized_options = b'\222A\t\n\007Release\202\323\344\223\002Q*O/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneNamespacePipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneNamespacePipelineRelease']._serialized_options = b'\222A\t\n\007Release\202\323\344\223\002Z\"U/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}/clone:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerNamespacePipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerNamespacePipelineRelease']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002\\\"W/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncNamespacePipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncNamespacePipelineRelease']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002b\"]/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/releases/{release_id}/trigger-async:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateNamespaceSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateNamespaceSecret']._serialized_options = b'\222A\010\n\006Secret\202\323\344\223\0023\")/v1beta/namespaces/{namespace_id}/secrets:\006secret'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListNamespaceSecrets']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListNamespaceSecrets']._serialized_options = b'\222A\010\n\006Secret\202\323\344\223\002+\022)/v1beta/namespaces/{namespace_id}/secrets'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetNamespaceSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetNamespaceSecret']._serialized_options = b'\222A\010\n\006Secret\202\323\344\223\0027\0225/v1beta/namespaces/{namespace_id}/secrets/{secret_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateNamespaceSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateNamespaceSecret']._serialized_options = b'\222A\010\n\006Secret\202\323\344\223\002?25/v1beta/namespaces/{namespace_id}/secrets/{secret_id}:\006secret'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteNamespaceSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteNamespaceSecret']._serialized_options = b'\222A\010\n\006Secret\202\323\344\223\0027*5/v1beta/namespaces/{namespace_id}/secrets/{secret_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListComponentDefinitions']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListComponentDefinitions']._serialized_options = b'\222A\013\n\tComponent\202\323\344\223\002\037\022\035/v1beta/component-definitions'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperation']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperation']._serialized_options = b'\222A\246\001\n\007Triggerr\232\001\n\227\001\n\025Instill-Requester-Uid\022|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002#\022!/v1beta/operations/{operation_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\"\"/v1beta/{parent=users/*}/pipelines:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelines']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002$\022\"/v1beta/{parent=users/*}/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002$\022\"/v1beta/{name=users/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\00272+/v1beta/{pipeline.name=users/*/pipelines/*}:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002$*\"/v1beta/{name=users/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateUserPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0020\"+/v1beta/{name=users/*/pipelines/*}/validate:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\")/v1beta/{name=users/*/pipelines/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/\"*/v1beta/{name=users/*/pipelines/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipelineWithStream']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipelineWithStream']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0026\"1/v1beta/{name=users/*/pipelines/*}/trigger-stream:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0024\"//v1beta/{name=users/*/pipelines/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0028\"-/v1beta/{parent=users/*/pipelines/*}/releases:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelineReleases']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelineReleases']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/\022-/v1beta/{parent=users/*/pipelines/*}/releases'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/\022-/v1beta/{name=users/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002@25/v1beta/{release.name=users/*/pipelines/*/releases/*}:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/*-/v1beta/{name=users/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreUserPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0027\"5/v1beta/{name=users/*/pipelines/*/releases/*}/restore'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0029\"4/v1beta/{name=users/*/pipelines/*/releases/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002:\"5/v1beta/{name=users/*/pipelines/*/releases/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002?\":/v1beta/{name=users/*/pipelines/*/releases/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0026\"*/v1beta/{parent=organizations/*}/pipelines:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelines']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022*/v1beta/{parent=organizations/*}/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022*/v1beta/{name=organizations/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002?23/v1beta/{pipeline.name=organizations/*/pipelines/*}:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,**/v1beta/{name=organizations/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateOrganizationPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0028\"3/v1beta/{name=organizations/*/pipelines/*}/validate:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0026\"1/v1beta/{name=organizations/*/pipelines/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipelineStream']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipelineStream']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002>\"9/v1beta/{name=organizations/*/pipelines/*}/trigger-stream:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0027\"2/v1beta/{name=organizations/*/pipelines/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipeline']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002<\"7/v1beta/{name=organizations/*/pipelines/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002@\"5/v1beta/{parent=organizations/*/pipelines/*}/releases:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelineReleases']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelineReleases']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0027\0225/v1beta/{parent=organizations/*/pipelines/*}/releases'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0027\0225/v1beta/{name=organizations/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002H2=/v1beta/{release.name=organizations/*/pipelines/*/releases/*}:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0027*5/v1beta/{name=organizations/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreOrganizationPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002?\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/restore'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002A\"</v1beta/{name=organizations/*/pipelines/*/releases/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002B\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipelineRelease']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002G\"B/v1beta/{name=organizations/*/pipelines/*/releases/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectorDefinitions']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectorDefinitions']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\037\022\035/v1beta/connector-definitions'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetConnectorDefinition']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetConnectorDefinition']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002(\022&/v1beta/{name=connector-definitions/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOperatorDefinitions']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOperatorDefinitions']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\036\022\034/v1beta/operator-definitions'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperatorDefinition']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperatorDefinition']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\'\022%/v1beta/{name=operator-definitions/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['CheckName']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CheckName']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\027\"\022/v1beta/check-name:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserSecret']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002*\" /v1beta/{parent=users/*}/secrets:\006secret'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserSecrets']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserSecrets']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"\022 /v1beta/{parent=users/*}/secrets'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserSecret']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"\022 /v1beta/{name=users/*/secrets/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserSecret']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\00212\'/v1beta/{secret.name=users/*/secrets/*}:\006secret'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserSecret']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"* /v1beta/{name=users/*/secrets/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationSecret']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0022\"(/v1beta/{parent=organizations/*}/secrets:\006secret'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationSecrets']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationSecrets']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002*\022(/v1beta/{parent=organizations/*}/secrets'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationSecret']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002*\022(/v1beta/{name=organizations/*/secrets/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationSecret']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\00292//v1beta/{secret.name=organizations/*/secrets/*}:\006secret'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationSecret']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationSecret']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002**(/v1beta/{name=organizations/*/secrets/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelineRuns']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelineRuns']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002@\022>/v1beta/namespaces/{namespace_id}/pipelines/{pipeline_id}/runs'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListComponentRuns']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListComponentRuns']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\0028\0226/v1beta/pipeline-runs/{pipeline_run_id}/component-runs'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelineRunsByCreditOwner']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelineRunsByCreditOwner']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002\"\022 /v1beta/dashboard/pipelines/runs'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListNamespaceConnections']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListNamespaceConnections']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002/\022-/v1beta/namespaces/{namespace_id}/connections'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetNamespaceConnection']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetNamespaceConnection']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002?\022=/v1beta/namespaces/{namespace_id}/connections/{connection_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateNamespaceConnection']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateNamespaceConnection']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002F\"8/v1beta/namespaces/{connection.namespace_id}/connections:\nconnection'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateNamespaceConnection']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateNamespaceConnection']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002V2H/v1beta/namespaces/{connection.namespace_id}/connections/{connection_id}:\nconnection'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteNamespaceConnection']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteNamespaceConnection']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002?*=/v1beta/namespaces/{namespace_id}/connections/{connection_id}'
  _PIPELINEPUBLICSERVICE.methods_by_name['TestNamespaceConnection']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TestNamespaceConnection']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002D\"B/v1beta/namespaces/{namespace_id}/connections/{connection_id}/test'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelineIDsByConnectionID']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelineIDsByConnectionID']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002T\022R/v1beta/namespaces/{namespace_id}/connections/{connection_id}/referenced-pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListIntegrations']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListIntegrations']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002\026\022\024/v1beta/integrations'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetIntegration']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetIntegration']._serialized_options = b'\222A\r\n\013Integration\202\323\344\223\002\'\022%/v1beta/integrations/{integration_id}'
  _globals['_PIPELINEPUBLICSERVICE']._serialized_start=374
  _globals['_PIPELINEPUBLICSERVICE']._serialized_end=23134
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from artifact.artifact.v1alpha import chunk_pb2 as artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2
from artifact.artifact.v1alpha import file_catalog_pb2 as artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2
from artifact.artifact.v1alpha import object_pb2 as artifact_dot_artifact_dot_v1alpha_dot_object__pb2
from artifact.artifact.v1alpha import qa_pb2 as artifact_dot_artifact_dot_v1alpha_dot_qa__pb2


class ArtifactPublicServiceStub(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/Liveness',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/Readiness',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.FromString,
                )
        self.CreateCatalog = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/CreateCatalog',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateCatalogRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateCatalogResponse.FromString,
                )
        self.ListCatalogs = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListCatalogs',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogsRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogsResponse.FromString,
                )
        self.UpdateCatalog = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateCatalog',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateCatalogRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateCatalogResponse.FromString,
                )
        self.DeleteCatalog = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteCatalog',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogResponse.FromString,
                )
        self.UploadCatalogFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UploadCatalogFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadCatalogFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadCatalogFileResponse.FromString,
                )
        self.DeleteCatalogFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteCatalogFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogFileResponse.FromString,
                )
        self.ProcessCatalogFiles = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ProcessCatalogFiles',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessCatalogFilesRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessCatalogFilesResponse.FromString,
                )
        self.ListCatalogFiles = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListCatalogFiles',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogFilesRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogFilesResponse.FromString,
                )
        self.ListChunks = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListChunks',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.FromString,
                )
        self.GetSourceFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/GetSourceFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.FromString,
                )
        self.UpdateChunk = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateChunk',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.FromString,
                )
        self.SimilarityChunksSearch = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/SimilarityChunksSearch',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.FromString,
                )
        self.QuestionAnswering = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/QuestionAnswering',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_qa__pb2.QuestionAnsweringRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_qa__pb2.QuestionAnsweringResponse.FromString,
                )
        self.GetFileCatalog = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/GetFileCatalog',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2.GetFileCatalogRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2.GetFileCatalogResponse.FromString,
                )
        self.ListCatalogRuns = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListCatalogRuns',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogRunsRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogRunsResponse.FromString,
                )
        self.GetObjectUploadURL = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/GetObjectUploadURL',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectUploadURLRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectUploadURLResponse.FromString,
                )
        self.GetObjectDownloadURL = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/GetObjectDownloadURL',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectDownloadURLRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectDownloadURLResponse.FromString,
                )


class ArtifactPublicServiceServicer(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def Liveness(self, request, context):
        """Check if the artifact server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the artifact server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCatalog(self, request, context):
        """TODO improve public endpoint definitions with title and description.

        Create a catalog
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCatalogs(self, request, context):
        """Get all catalogs info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCatalog(self, request, context):
        """Update a catalog info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCatalog(self, request, context):
        """Delete a catalog
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCatalogFile(self, request, context):
        """Create a file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCatalogFile(self, request, context):
        """Delete a file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProcessCatalogFiles(self, request, context):
        """Process catalog files
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCatalogFiles(self, request, context):
        """List catalog files
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListChunks(self, request, context):
        """List catalog chunks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSourceFile(self, request, context):
        """Get catalog single-source-of-truth file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateChunk(self, request, context):
        """Update catalog chunk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimilarityChunksSearch(self, request, context):
        """Retrieve similar chunks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuestionAnswering(self, request, context):
        """Ask a question
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFileCatalog(self, request, context):
        """Get file catalog
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCatalogRuns(self, request, context):
        """List Catalog Runs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectUploadURL(self, request, context):
        """Get Object Upload URL
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectDownloadURL(self, request, context):
        """Get Object Download URL
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ArtifactPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.SerializeToString,
            ),
            'CreateCatalog': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCatalog,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateCatalogRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateCatalogResponse.SerializeToString,
            ),
            'ListCatalogs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCatalogs,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogsRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogsResponse.SerializeToString,
            ),
            'UpdateCatalog': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCatalog,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateCatalogRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateCatalogResponse.SerializeToString,
            ),
            'DeleteCatalog': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCatalog,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogResponse.SerializeToString,
            ),
            'UploadCatalogFile': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCatalogFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadCatalogFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadCatalogFileResponse.SerializeToString,
            ),
            'DeleteCatalogFile': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCatalogFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogFileResponse.SerializeToString,
            ),
            'ProcessCatalogFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ProcessCatalogFiles,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessCatalogFilesRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessCatalogFilesResponse.SerializeToString,
            ),
            'ListCatalogFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCatalogFiles,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogFilesRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogFilesResponse.SerializeToString,
            ),
            'ListChunks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListChunks,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.SerializeToString,
            ),
            'GetSourceFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSourceFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.SerializeToString,
            ),
            'UpdateChunk': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateChunk,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.SerializeToString,
            ),
            'SimilarityChunksSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.SimilarityChunksSearch,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.SerializeToString,
            ),
            'QuestionAnswering': grpc.unary_unary_rpc_method_handler(
                    servicer.QuestionAnswering,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_qa__pb2.QuestionAnsweringRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_qa__pb2.QuestionAnsweringResponse.SerializeToString,
            ),
            'GetFileCatalog': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileCatalog,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2.GetFileCatalogRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2.GetFileCatalogResponse.SerializeToString,
            ),
            'ListCatalogRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCatalogRuns,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogRunsRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogRunsResponse.SerializeToString,
            ),
            'GetObjectUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectUploadURL,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectUploadURLRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectUploadURLResponse.SerializeToString,
            ),
            'GetObjectDownloadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectDownloadURL,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectDownloadURLRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectDownloadURLResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'artifact.artifact.v1alpha.ArtifactPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ArtifactPublicService(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/Liveness',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/Readiness',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCatalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/CreateCatalog',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateCatalogRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateCatalogResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCatalogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListCatalogs',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogsRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCatalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateCatalog',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateCatalogRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateCatalogResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCatalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteCatalog',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCatalogFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UploadCatalogFile',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadCatalogFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadCatalogFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCatalogFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteCatalogFile',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteCatalogFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProcessCatalogFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ProcessCatalogFiles',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessCatalogFilesRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessCatalogFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCatalogFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListCatalogFiles',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogFilesRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListChunks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListChunks',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSourceFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/GetSourceFile',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateChunk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateChunk',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimilarityChunksSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/SimilarityChunksSearch',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuestionAnswering(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/QuestionAnswering',
            artifact_dot_artifact_dot_v1alpha_dot_qa__pb2.QuestionAnsweringRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_qa__pb2.QuestionAnsweringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFileCatalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/GetFileCatalog',
            artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2.GetFileCatalogRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2.GetFileCatalogResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCatalogRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListCatalogRuns',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogRunsRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListCatalogRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/GetObjectUploadURL',
            artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectUploadURLRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectDownloadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/GetObjectDownloadURL',
            artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectDownloadURLRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_object__pb2.GetObjectDownloadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/task/v1alpha/task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ommon/task/v1alpha/task.proto\x12\x13\x63ommon.task.v1alpha*\xd3\x02\n\x04Task\x12\x14\n\x10TASK_UNSPECIFIED\x10\x00\x12\x17\n\x13TASK_CLASSIFICATION\x10\x01\x12\x12\n\x0eTASK_DETECTION\x10\x02\x12\x11\n\rTASK_KEYPOINT\x10\x03\x12\x0c\n\x08TASK_OCR\x10\x04\x12\x1e\n\x1aTASK_INSTANCE_SEGMENTATION\x10\x05\x12\x1e\n\x1aTASK_SEMANTIC_SEGMENTATION\x10\x06\x12\x16\n\x12TASK_TEXT_TO_IMAGE\x10\x07\x12\x17\n\x13TASK_IMAGE_TO_IMAGE\x10\x0b\x12\x12\n\x0eTASK_EMBEDDING\x10\x0c\x12\x1b\n\x17TASK_SPEECH_RECOGNITION\x10\r\x12\r\n\tTASK_CHAT\x10\x0e\x12\x13\n\x0fTASK_COMPLETION\x10\x0f\x12\x0f\n\x0bTASK_CUSTOM\x10\x10\"\x04\x08\x08\x10\x08\"\x04\x08\t\x10\t\"\x04\x08\n\x10\nB\xd5\x01\n\x17\x63om.common.task.v1alphaB\tTaskProtoP\x01ZAgithub.com/instill-ai/protogen-go/common/task/v1alpha;taskv1alpha\xa2\x02\x03\x43TX\xaa\x02\x13\x43ommon.Task.V1alpha\xca\x02\x13\x43ommon\\Task\\V1alpha\xe2\x02\x1f\x43ommon\\Task\\V1alpha\\GPBMetadata\xea\x02\x15\x43ommon::Task::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.task.v1alpha.task_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.common.task.v1alphaB\tTaskProtoP\001ZAgithub.com/instill-ai/protogen-go/common/task/v1alpha;taskv1alpha\242\002\003CTX\252\002\023Common.Task.V1alpha\312\002\023Common\\Task\\V1alpha\342\002\037Common\\Task\\V1alpha\\GPBMetadata\352\002\025Common::Task::V1alpha'
  _globals['_TASK']._serialized_start=56
  _globals['_TASK']._serialized_end=395
# @@protoc_insertion_point(module_scope)
